Provisioning Plugins
====================

This page lists all available provisioning plugins. In general a plugin
enables Savanna to deploy a specific Hadoop version/distribution in
various topologies and with management/monitoring tools.

:doc:`vanilla_plugin` - deploys Vanilla Apache Hadoop